exceptiontools.MissingInstrumentError
=====================================

.. inheritance-diagram:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
